.. :changelog:

History
-------

0.1.0 (2013-10-19)
++++++++++++++++++

* First public release.

0.1.1 (2013-10-20)
++++++++++++++++++

* Improved documentation on how to fix installation in case of missing libraries.